@@ -3,7 +3,7 @@ export.design <- function(design, response.names=NULL, path=".", filename=NULL,
      if (!(is.null(response.names) | is.character(response.names))) 
          stop("response.names must be a character vector of response names or NULL")
      if (!is.logical(replace)) stop("replace must be logical")
-     if (!type %in% c("rda","html","csv")) stop("type must be one of rda, html or csv")
+     if (!type %in% c("rda","html","csv","all")) stop("type must be one of rda, html, csv, or all")
      if (!OutDec %in% c(".",",")) stop("OutDec must be one of . or ,")
      if (!(is.null(legend) | is.data.frame(legend))) stop("legend must be a data frame with legend information")
      desname <- deparse(substitute(design))
@@ -28,21 +28,28 @@ export.design <- function(design, response.names=NULL, path=".", filename=NULL,
            if (tolower(paste(filename,"rda",sep=".")) %in% lf) 
                stop("file ", paste(filename,"rda","."), " exists in the chosen directory and is not replaced (replace=FALSE). Change directory, filename, or replace option.")
          }
-     if (type=="html"){
+     if (type %in% c("html","all")){
          if (!replace){ 
            if (tolower(paste(filename,"html",sep=".")) %in% lf) 
                stop("file ", paste(filename,"html","."), " exists and is not replaced (replace=FALSE). Change directory, filename, or replace option.")
          }
          if (is.null(legend)){
-             fn <- design.info(design)$factor.names
+             di <- design.info(design)
+             if (length(grep("param",di$type))>0 & length(grep("wide",di$type))>0){
+                 outer <- cbind(run.no.outer=1:nrow(di$outer),di$outer)
+                 hilf <- matrix(rep("",(di$nruns-nrow(outer))*ncol(outer)),ncol=ncol(outer))
+                 colnames(hilf) <- colnames(outer)
+                 outer <- rbind(outer, hilf)
+                 }
+             fn <- di$factor.names
              ncols <- max(sapply(fn, "length"))
              for (i in 1:length(fn)) if (length(fn[[i]])<ncols) fn[[i]] <- c(fn[[i]], rep("",ncols-length(fn[[i]])))
              cn <- c("Factor", paste("Level",1:ncols,sep=""))
              legend <- data.frame(names(fn))
              for (i in 1:ncols) legend <- cbind(legend,sapply(fn, function(obj) obj[i]))
              colnames(legend) <- cn
-             if (!is.call(design.info(design)$creator)){
-                 fn <- design.info(design)$creator$faclablist
+             if (!is.call(di$creator)){
+                 fn <- di$creator$faclablist
                  if (!all(fn=="")){
                       ## provision for extra error check columns for screening designs
                       if (nrow(legend) > length(fn)) fn <- c(fn, rep("error checking column", nrow(legend)-length(fn)))
@@ -52,14 +59,17 @@ export.design <- function(design, response.names=NULL, path=".", filename=NULL,
          }
          hilf <- matrix("",nrow=nrow(df)-nrow(legend),ncol=ncol(legend))
          colnames(hilf) <- colnames(legend)
-         df <- cbind(df, "_"=rep("",nrow(df)))
-         df <- cbind(df, rbind(legend,hilf))
-         html(df,file=paste(path,paste(filename,"html",sep="."),sep="/"),OutDec=OutDec, ...)
+         dfn <- cbind(df, "_"=rep("",nrow(df)))
+         rownames(dfn) <- rownames(design)     ## so that legend rownames cannot overwrite this
+         if (length(grep("param",di$type))>0 & length(grep("wide",di$type))>0) 
+               dfn <- cbind(dfn, outer, "."=rep("",nrow(dfn)), rbind(legend,hilf))
+         else dfn <- cbind(dfn, rbind(legend,hilf))
+         html(dfn,file=paste(path,paste(filename,"html",sep="."),sep="/"),OutDec=OutDec, ...)
      }
-     if (type=="csv") {
+     if (type %in% c("csv","all")) {
          if (!replace){ 
            if (tolower(paste(filename,"csv",sep=".")) %in% lf) 
-               stop("file ", paste(filename,"csv","."), " exists and is not replaced (replace=FALSE).  Change directory, filename, or replace option.")
+               stop("file ", paste(filename,"csv","."), " exists and is not replaced (replace=FALSE). \nChange directory, filename, or replace option.")
          }
          if (OutDec==",") write.csv2(df, file=paste(path,paste(filename,"csv",sep="."),sep="/"))
          else write.csv(df, file=paste(path,paste(filename,"csv",sep="."),sep="/"))
